@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@
 #define MAX_TOTAL_PIDS	8000
 #define MAXIPTENT	2000
 
-/* minimal per VE values */
+/* minimal per CT values */
 #define MINPROC		30
 #define MINTCPBUF	65536
 #define MINDGRAMBUF	32768
@@ -61,7 +61,7 @@
 #define MIN_PGLOCK	4
 #define MIN_GUARPG	1024
 
-/* maximal per VE values */
+/* maximal per CT values */
 #define PRIVVM_PVE	0.6 / 4096
 #define IPTENT_PVE	200
 #define FLOCK_PVE	1000
@@ -176,16 +176,17 @@ char *level_string[MAX_SL+1] = {
 void usage(int rc)
 {
 	fprintf(rc ? stderr : stdout, "Usage: vzsplit [-f config_name] "
-			"| [-n numves] | [-s swap_size\n"
+			"| [-n numves] | [-s swap_size]\n"
 		"\t -f specified config name\n"
-		"\t -n specified number of VEs\n"
+		"\t -n specified number of containers\n"
 		"\t -s specified swap in Kbytes\n");
 	exit(rc);
 }
 
 void header(FILE *fp)
 {
-	fprintf(fp,"# Configuration file generated by vzsplit for %d VEs\n"
+	fprintf(fp,
+		"# Configuration file generated by vzsplit for %d containers\n"
 		"# on HN with total amount of physical mem %llu Mb\n"
 		"# low memory %llu Mb, swap size %llu Mb, Max treads %lu\n"
 		"# Resourse commit level %d:\n# %s\n",
@@ -318,8 +319,8 @@ int calculate_values()
 		} while  ((rest < 0) && (numproc > MINPROC));
 
 		if (rest < 0) {
-			fprintf(stderr, "Fatal resource shortage, "
-					"try to decrease the number of VEs\n");
+			fprintf(stderr, "Fatal resource shortage, try to "
+					"decrease the number of containers\n");
 			return 1;
 		}
 		params[DGRAM].lim = params[DGRAM].bar = MINDGRAMBUF;
@@ -513,7 +514,7 @@ int check_disk_space() {
 	}
 	if (retval == 1) {
 		fprintf(stderr, "WARNING: partition holding %s do not "
-				"have space required for %d VEs\n"
+				"have space required for %d containers\n"
 				"The maximum allowed value is %d\n",
 				ve_private, num_ve, ve_allowed);
 		fprintf(stderr, "Default disk space values "
@@ -589,14 +590,14 @@ int main(int argc, char **argv)
 		usage(1);
 	}
 	if (num_ve == -1) {
-		printf("Enter the number of VEs: ");
+		printf("Enter the number of containers: ");
 		if (scanf("%d", &num_ve) != 1) {
 			fprintf(stderr, "Invalid value.\n");
 			exit(1);
 		}
 	}
 	if (num_ve < 1) {
-		fprintf(stderr, "Incorrect value for number of VEs.\n");
+		fprintf(stderr, "Incorrect value for number of containers.\n");
 		exit(1);
 	}
 
@@ -631,7 +632,7 @@ int main(int argc, char **argv)
 
 	if (((mem_total + swap_total - SYSRSRV) / num_ve) < MEMPERVE) {
 		fprintf(stderr, "On node with %llu Mb of memory (RAM + swap) "
-				"%d VEs can not be allocated\n",
+				"%d containers can not be allocated\n",
 				(mem_total + swap_total) >> 20, num_ve);
 		ve_allowed = (mem_total + swap_total - SYSRSRV) / MEMPERVE;
 		retval = 1;
@@ -641,7 +642,7 @@ int main(int argc, char **argv)
 		int ve_low;
 
 		fprintf(stderr, "On node with %llu Mb of Low Memory "
-				"%d VEs can not be allocated\n",
+				"%d containers can not be allocated\n",
 				low_total >> 20, num_ve);
 		ve_low = (low_total - SYSRSRV) / LOWPERVE;
 		if (ve_low < ve_allowed)
